# ValidateAntiForgeryTokenAttribute


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**order** | **int** |  | [optional] 
**is_reusable** | **bool** |  | [optional] [readonly] 
**type_id** | **bool, date, datetime, dict, float, int, list, str, none_type** |  | [optional] [readonly] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


